scrumlab_link library
This library holds just one Material widget It will wrap a child with an InkWell and launch (if possible) the provided URL In case it's not possible to launch the URL, it will call the provided onError function if provided
Classes
- Link
- Wraps a linkable element around child, opening the provided URL as a String